Crate solana_vanity

Crate solana_vanity 

Library for generating Solana vanity addresses.

Structs

VanityResult
Result of a successful vanity address search.

Functions

find_vanity_address
Searches for a Solana keypair whose public key starts with the given prefix. Uses the specified number of threads.
find_vanity_address_with_suffix
Searches for a Solana keypair whose public key ends with the given suffix. Uses the specified number of threads.